@@ -1,7 +1,7 @@
 // padthv1.cpp
 //
 /****************************************************************************
-   Copyright (C) 2012-2019, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2012-2020, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -2084,8 +2084,8 @@ void padthv1_impl::process ( float **ins, float **outs, uint32_t nframes )
 				// filters
 
 				if (dcf1_enabled) {
-					const float env1 = 0.5f * (1.0f + vel1
-						* *m_dcf1.envelope * pv->dcf1_env.tick());
+					const float env1 = 0.5f
+						* (1.0f + *m_dcf1.envelope * pv->dcf1_env.tick());
 					const float cutoff1 = padthv1_sigmoid_1(*m_dcf1.cutoff
 						* env1 * (1.0f + *m_lfo1.cutoff * lfo1));
 					const float reso1 = padthv1_sigmoid_1(*m_dcf1.reso
