@@ -1,7 +1,7 @@
 // padthv1_jack.h
 //
 /****************************************************************************
-   Copyright (C) 2012-2019, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2012-2020, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -73,6 +73,8 @@ public:
 protected:
 
 	void updatePreset(bool bDirty);
+	void updateParam(padthv1::ParamIndex index);
+	void updateParams();
 	void updateTuning();
 
 private:
