@@ -1,7 +1,7 @@
 // padthv1widget.cpp
 //
 /****************************************************************************
-   Copyright (C) 2012-2019, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2012-2020, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -52,8 +52,8 @@
 //
 
 // Constructor.
-padthv1widget::padthv1widget ( QWidget *pParent, Qt::WindowFlags wflags )
-	: QWidget(pParent, wflags), p_ui(new Ui::padthv1widget), m_ui(*p_ui)
+padthv1widget::padthv1widget ( QWidget *pParent )
+	: QWidget(pParent), p_ui(new Ui::padthv1widget), m_ui(*p_ui)
 {
 	Q_INIT_RESOURCE(padthv1);
 
@@ -95,7 +95,7 @@ padthv1widget::padthv1widget ( QWidget *pParent, Qt::WindowFlags wflags )
 	// Note names.
 	QStringList notes;
 	for (int note = 0; note < 128; ++note)
-		notes << padthv1_ui::noteName(note).remove(QRegExp("/\\S+"));
+		notes << padthv1_ui::noteName(note).remove(QRegularExpression("/\\S+"));
 
 	m_ui.Gen1Sample1Knob->setScale(1000.0f);
 	m_ui.Gen1Sample1Knob->insertItems(0, notes);
@@ -509,6 +509,10 @@ padthv1widget::padthv1widget ( QWidget *pParent, Qt::WindowFlags wflags )
 	setParamKnob(padthv1::DYN1_COMPRESS, m_ui.Dyn1CompressKnob);
 	setParamKnob(padthv1::DYN1_LIMITER,  m_ui.Dyn1LimiterKnob);
 
+    // added by scotty to try to support linnstruments need for bigger bend range
+    m_ui.Def1PitchbendKnob->setMinimum(0.0f);
+    m_ui.Def1PitchbendKnob->setMaximum(+4.0f);
+
 
 	// Preset management
 	QObject::connect(m_ui.Preset,
@@ -544,6 +548,11 @@ padthv1widget::padthv1widget ( QWidget *pParent, Qt::WindowFlags wflags )
 		SIGNAL(sampleChanged()),
 		SLOT(resetSample2()));
 
+	// Randomize params...
+	QObject::connect(m_ui.PanicButton,
+		SIGNAL(clicked()),
+		SLOT(panic()));
+	
 	// Direct stacked-page signal/slot
 	QObject::connect(m_ui.TabBar, SIGNAL(currentChanged(int)),
 		m_ui.StackedWidget, SLOT(setCurrentIndex(int)));
@@ -904,6 +913,15 @@ void padthv1widget::swapParams ( bool bOn )
 }
 
 
+// Panic: all-notes/sound-off (reset).
+void padthv1widget::panic (void)
+{
+	padthv1_ui *pSynthUi = ui_instance();
+	if (pSynthUi)
+		pSynthUi->reset();
+}
+
+
 // Reset swap params A/B group.
 void padthv1widget::resetSwapParams (void)
 {
