@@ -1,7 +1,7 @@
 // padthv1widget_palette.cpp
 //
 /****************************************************************************
-   Copyright (C) 2012-2019, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2012-2020, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -74,6 +74,9 @@ static struct
 	{ "LinkVisited",     QPalette::LinkVisited     },
 	{ "ToolTipBase",     QPalette::ToolTipBase     },
 	{ "ToolTipText",     QPalette::ToolTipText     },
+#if QT_VERSION >= QT_VERSION_CHECK(5, 12, 0)
+	{ "PlaceholderText", QPalette::PlaceholderText },
+#endif
 	{ "NoRole",          QPalette::NoRole          },
 
 	{  nullptr,          QPalette::NoRole          }
@@ -111,9 +114,6 @@ padthv1widget_palette::padthv1widget_palette ( QWidget *parent, const QPalette&
 	m_ui.paletteView->setColumnHidden(2, true);
 	m_ui.paletteView->setColumnHidden(3, true);
 
-	QObject::connect(m_ui.nameCombo,
-		SIGNAL(activated(const QString&)),
-		SLOT(nameComboActivated(const QString&)));
 	QObject::connect(m_ui.nameCombo,
 		SIGNAL(editTextChanged(const QString&)),
 		SLOT(nameComboChanged(const QString&)));
@@ -225,18 +225,14 @@ QSettings *padthv1widget_palette::settings (void) const
 }
 
 
-void padthv1widget_palette::nameComboActivated ( const QString& name )
-{
-	setPaletteName(name);
-}
-
-
 void padthv1widget_palette::nameComboChanged ( const QString& name )
 {
-	if (m_dirtyCount > 0 || m_ui.nameCombo->findText(name) < 0)
+	if (m_dirtyCount > 0 || m_ui.nameCombo->findText(name) < 0) {
 		updateDialogButtons();
-	else
+	} else {
 		setPaletteName(name);
+		++m_dirtyTotal;
+	}
 }
 
 
@@ -512,7 +508,9 @@ bool padthv1widget_palette::namedPalette (
 	QSettings *settings, const QString& name, QPalette& pal, bool fixup )
 {
 	int result = 0;
+#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
 	uint mask = pal.resolve();
+#endif
 
 	// Custom color themes...
 	if (name == "Wonton Soup") {
@@ -573,7 +571,9 @@ bool padthv1widget_palette::namedPalette (
 		pal.setColor(QPalette::Active,   QPalette::LinkVisited, QColor(64, 128, 255));
 		pal.setColor(QPalette::Inactive, QPalette::LinkVisited, QColor(64, 128, 255));
 		pal.setColor(QPalette::Disabled, QPalette::LinkVisited, QColor(54, 76, 119));
+	#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
 		mask = 0;
+	#endif
 		++result;
 	}
 	else
@@ -635,7 +635,9 @@ bool padthv1widget_palette::namedPalette (
 		pal.setColor(QPalette::Active,   QPalette::LinkVisited, QColor(230, 100, 230));
 		pal.setColor(QPalette::Inactive, QPalette::LinkVisited, QColor(230, 100, 230));
 		pal.setColor(QPalette::Disabled, QPalette::LinkVisited, QColor(74, 34, 74));
+	#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
 		mask = 0;
+	#endif
 		++result;
 	}
 	else
@@ -653,7 +655,9 @@ bool padthv1widget_palette::namedPalette (
 				pal.setColor(QPalette::Active,   cr, QColor(clist.at(0)));
 				pal.setColor(QPalette::Inactive, cr, QColor(clist.at(1)));
 				pal.setColor(QPalette::Disabled, cr, QColor(clist.at(2)));
+			#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
 				mask &= ~(1 << int(cr));
+			#endif
 				++result;
 			}
 		}
@@ -692,7 +696,9 @@ bool padthv1widget_palette::namedPalette (
 		++result;
 	}
 
+#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
 	pal.resolve(mask);
+#endif
 	return (result > 0);
 }
 
@@ -963,22 +969,22 @@ bool padthv1widget_palette::PaletteModel::setData (
 		if (m_generate) {
 			m_palette.setBrush(QPalette::Inactive, cr, color);
 			switch (cr) {
-				case QPalette::Foreground:
+				case QPalette::WindowText:
 				case QPalette::Text:
 				case QPalette::ButtonText:
 				case QPalette::Base:
 					break;
 				case QPalette::Dark:
-					m_palette.setBrush(QPalette::Disabled, QPalette::Foreground, color);
+					m_palette.setBrush(QPalette::Disabled, QPalette::WindowText, color);
 					m_palette.setBrush(QPalette::Disabled, QPalette::Dark, color);
 					m_palette.setBrush(QPalette::Disabled, QPalette::Text, color);
 					m_palette.setBrush(QPalette::Disabled, QPalette::ButtonText, color);
 					index_begin = PaletteModel::index(0, 0);
 					index_end = PaletteModel::index(m_nrows - 1, 3);
 					break;
-				case QPalette::Background:
+				case QPalette::Window:
 					m_palette.setBrush(QPalette::Disabled, QPalette::Base, color);
-					m_palette.setBrush(QPalette::Disabled, QPalette::Background, color);
+					m_palette.setBrush(QPalette::Disabled, QPalette::Window, color);
 					index_begin = PaletteModel::index(QPalette::Base, 0);
 					break;
 				case QPalette::Highlight:
@@ -1257,7 +1263,7 @@ padthv1widget_palette::ColorEditor::ColorEditor ( QWidget *parent )
 	: QWidget(parent)
 {
 	QLayout *layout = new QHBoxLayout(this);
-	layout->setMargin(0);
+	layout->setContentsMargins(0, 0, 0, 0);
 	m_button = new padthv1widget_palette::ColorButton(this);
 	layout->addWidget(m_button);
 	QObject::connect(m_button,
@@ -1303,7 +1309,7 @@ padthv1widget_palette::RoleEditor::RoleEditor ( QWidget *parent )
 	m_edited = false;
 
 	QHBoxLayout *layout = new QHBoxLayout(this);
-	layout->setMargin(0);
+	layout->setContentsMargins(0, 0, 0, 0);
 	layout->setSpacing(0);
 
 	m_label = new QLabel(this);
